"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import customers as shared_customers
from typing import Optional



@dataclasses.dataclass
class ListCustomersRequest:
    cursor: Optional[int] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'cursor', 'style': 'form', 'explode': True }})
    r"""Cursor for pagination. This can be populated by the `next_cursor` value returned from the initial request."""
    limit: Optional[int] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'limit', 'style': 'form', 'explode': True }})
    r"""The number of items to fetch. Defaults to 20."""
    




@dataclasses.dataclass
class ListCustomersResponse:
    content_type: str = dataclasses.field()
    status_code: int = dataclasses.field()
    customers: Optional[shared_customers.Customers] = dataclasses.field(default=None)
    r"""OK"""
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    

