"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import upcominginvoice as shared_upcominginvoice
from typing import Optional



@dataclasses.dataclass
class FetchUpcomingInvoiceRequest:
    subscription_id: str = dataclasses.field(metadata={'query_param': { 'field_name': 'subscription_id', 'style': 'form', 'explode': True }})
    




@dataclasses.dataclass
class FetchUpcomingInvoiceResponse:
    content_type: str = dataclasses.field()
    status_code: int = dataclasses.field()
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    upcoming_invoice: Optional[shared_upcominginvoice.UpcomingInvoice] = dataclasses.field(default=None)
    r"""OK"""
    

