"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class ViewMode(str, Enum):
    PERIODIC = 'periodic'
    CUMULATIVE = 'cumulative'
