"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import creditledgerentry as shared_creditledgerentry
from ..shared import newcreditledgerentry as shared_newcreditledgerentry
from typing import Optional



@dataclasses.dataclass
class AddLedgerEntryExternalIDRequest:
    external_customer_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'external_customer_id', 'style': 'simple', 'explode': False }})
    new_credit_ledger_entry: Optional[shared_newcreditledgerentry.NewCreditLedgerEntry] = dataclasses.field(default=None, metadata={'request': { 'media_type': 'application/json' }})
    




@dataclasses.dataclass
class AddLedgerEntryExternalIDResponse:
    content_type: str = dataclasses.field()
    status_code: int = dataclasses.field()
    credit_ledger_entry: Optional[shared_creditledgerentry.CreditLedgerEntry] = dataclasses.field(default=None)
    r"""OK"""
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    

