"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class BackfillStatus(str, Enum):
    r"""The status of the backfill."""
    PENDING = 'pending'
    REFLECTED = 'reflected'
    PENDING_REVERT = 'pending_revert'
    REVERTED = 'reverted'
