"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class SubscriptionStatus(str, Enum):
    ACTIVE = 'active'
    ENDED = 'ended'
    UPCOMING = 'upcoming'
