"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import creditnote as shared_creditnote
from typing import Optional



@dataclasses.dataclass
class FetchCreditNoteRequest:
    credit_note_id: str = dataclasses.field(metadata={'path_param': { 'field_name': 'credit_note_id', 'style': 'simple', 'explode': False }})
    r"""The ID of the desired credit note."""
    




@dataclasses.dataclass
class FetchCreditNoteResponse:
    content_type: str = dataclasses.field()
    status_code: int = dataclasses.field()
    credit_note: Optional[shared_creditnote.CreditNote] = dataclasses.field(default=None)
    r"""OK"""
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)
    

