"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class DiscountType(str, Enum):
    PERCENTAGE = 'percentage'
    TRIAL = 'trial'
    USAGE = 'usage'
    AMOUNT = 'amount'
